==> Tridium_EMEA_N4_Supervisor-4.10.11.12.zip: rc/fe/CircleOfTrustMgrModel.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
/**
 * @copyright 2019 Tridium, Inc. All Rights Reserved.
 * @author Robert Staley
 */

/**
 * API Status: **Private**
 * @module nmodule/saml/rc/fe/CircleOfTrustMgrModel
 */
define(['baja!', 'jquery', 'Promise', 'nmodule/webEditors/rc/wb/mgr/model/MgrModel'], function (baja, $, Promise, MgrModel) {
  'use strict';

  /**
   * A layer that extends edit/add/remove functionality on top of a
   * `MgrModel`.
   *
   * @class
   * @alias module:nmodule/saml/rc/fe/CircleOfTrustMgrModel
   * @extends module:nmodule/webEditors/rc/wb/mgr/model/MgrModel
   */
  return /*#__PURE__*/function (_MgrModel) {
    function CircleOfTrustMgrModel() {
      _classCallCheck(this, CircleOfTrustMgrModel);
      return _callSuper(this, CircleOfTrustMgrModel, arguments);
    }
    _inherits(CircleOfTrustMgrModel, _MgrModel);
    return _createClass(CircleOfTrustMgrModel, [{
      key: "addInstances",
      value: function addInstances(instances, names) {
        names = names || [];
        var source = this.getComponentSource(),
          batch = new baja.comm.Batch(),
          getNames = _.map(instances, function (instance, i) {
            return this.unparentAndGetPropName(instance, batch).then(function (prop) {
              return names[i] || prop;
            });
          });
        batch.commit();
        return Promise.all(getNames).then(function (names) {
          return source.addComponents(instances, names);
        });
      }
    }, {
      key: "unparentAndGetPropName",
      value: function unparentAndGetPropName(comp, batch) {
        var parent = comp.getParent(),
          prop = comp.getPropertyInParent();
        return Promise.resolve(parent && parent.remove({
          slot: prop,
          batch: batch
        })).then(function () {
          return prop && String(prop);
        });
      }
    }]);
  }(MgrModel);
});

==> Tridium_EMEA_N4_Supervisor-4.14.3.24.zip: rc/fe/CircleOfTrustMgrModel.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
/**
 * @copyright 2019 Tridium, Inc. All Rights Reserved.
 * @author Robert Staley
 */

/**
 * API Status: **Private**
 * @module nmodule/saml/rc/fe/CircleOfTrustMgrModel
 */
define(['baja!', 'jquery', 'Promise', 'underscore', 'nmodule/webEditors/rc/wb/mgr/model/MgrModel'], function (baja, $, Promise, _, MgrModel) {
  'use strict';

  /**
   * A layer that extends edit/add/remove functionality on top of a
   * `MgrModel`.
   *
   * @class
   * @alias module:nmodule/saml/rc/fe/CircleOfTrustMgrModel
   * @extends module:nmodule/webEditors/rc/wb/mgr/model/MgrModel
   */
  return /*#__PURE__*/function (_MgrModel) {
    function CircleOfTrustMgrModel() {
      _classCallCheck(this, CircleOfTrustMgrModel);
      return _callSuper(this, CircleOfTrustMgrModel, arguments);
    }
    _inherits(CircleOfTrustMgrModel, _MgrModel);
    return _createClass(CircleOfTrustMgrModel, [{
      key: "addInstances",
      value: function addInstances(instances, names) {
        names = names || [];
        var source = this.getComponentSource(),
          batch = new baja.comm.Batch(),
          getNames = _.map(instances, function (instance, i) {
            return this.unparentAndGetPropName(instance, batch).then(function (prop) {
              return names[i] || prop;
            });
          });
        batch.commit();
        return Promise.all(getNames).then(function (names) {
          return source.addComponents(instances, names);
        });
      }
    }, {
      key: "unparentAndGetPropName",
      value: function unparentAndGetPropName(comp, batch) {
        var parent = comp.getParent(),
          prop = comp.getPropertyInParent();
        return Promise.resolve(parent && parent.remove({
          slot: prop,
          batch: batch
        })).then(function () {
          return prop && String(prop);
        });
      }
    }]);
  }(MgrModel);
});
